@@ -11,7 +11,7 @@ use Perl6::Signature;
 use Moose::Util::TypeConstraints ();
 use MooseX::Meta::Signature::Combined;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our ($Declarator, $Offset);
 
@@ -147,7 +147,7 @@ sub make_proto_unwrap {
     }
 
     my ($vars, $param_spec) = parse_proto($proto);
-    my $inject = "my (${vars}) = MooseX::Meta::Signature::Combined->new(${param_spec})->validate(\@_);";
+    my $inject = "my (${vars}) = MooseX::Method::Signatures::validate(\\\@_, ${param_spec});";
 
     return $inject;
 }
@@ -241,6 +241,17 @@ sub inject_scope {
     });
 }
 
+sub validate {
+    my ($args, @param_spec) = @_;
+
+    my @named = grep { !ref $_ } @param_spec;
+    my @ret = MooseX::Meta::Signature::Combined->new(@param_spec)->validate(@{ $args });
+    return @ret unless @named;
+
+    my $named_vals = pop @ret;
+    return (@ret, map { $named_vals->{$_} } @named);
+}
+
 1;
 
 __END__
